@@ -53,30 +53,37 @@ const (
 	WorkspaceRefType RefType = "workspaces"
 )
 
-// RefTypes is the set of all supported reference types.  External RefTypes can be added to this map in order to add
-// RefTypes for external tooling
-var RefTypes = map[RefType]struct{}{BranchRefType: {}, RemoteRefType: {}, InternalRefType: {}, TagRefType: {}, WorkspaceRefType: {}}
+// HeadRefTypes are the ref types that point to a HEAD and contain a Commit struct. These are the types that are
+// returned by GetHeadRefs. Other ref types don't point to Commits necessarily, so aren't in this list and must be
+// asked for explicitly.
+var HeadRefTypes = map[RefType]struct{}{
+	BranchRefType:    {},
+	RemoteRefType:    {},
+	InternalRefType:  {},
+	TagRefType:       {},
+	WorkspaceRefType: {},
+}
 
 // PrefixForType returns what a reference string for a given type should start with
 func PrefixForType(refType RefType) string {
 	return refPrefix + string(refType) + "/"
 }
 
-type RefUpdateMode struct {
+type UpdateMode struct {
 	Force bool
 }
 
-var ForceUpdate = RefUpdateMode{true}
-var FastForwardOnly = RefUpdateMode{false}
+var ForceUpdate = UpdateMode{true}
+var FastForwardOnly = UpdateMode{false}
 
 // DoltRef is a reference to a commit.
 type DoltRef interface {
 	fmt.Stringer
 
-	// Type is the RefType of this ref
+	// GetType returns the RefType of this ref
 	GetType() RefType
 
-	// Path is the identifier for the reference
+	// GetPath returns the identifier for the reference
 	GetPath() string
 }
 
@@ -102,12 +109,12 @@ func EqualsStr(dr DoltRef, str string) bool {
 	return Equals(dr, other)
 }
 
-// String() converts the DoltRef to a reference string in the format refs/type/path
+// String converts the DoltRef to a reference string in the format refs/type/path
 func String(dr DoltRef) string {
 	return PrefixForType(dr.GetType()) + dr.GetPath()
 }
 
-// MarshalJson implements the json Marshaler interface to json encode DoltRefs as their string representation
+// MarshalJSON implements the json Marshaler interface to json encode DoltRefs as their string representation
 func MarshalJSON(dr DoltRef) ([]byte, error) {
 	str := dr.String()
 	data := make([]byte, len(str)+2)
@@ -133,7 +140,7 @@ func Parse(str string) (DoltRef, error) {
 		}
 	}
 
-	for rType := range RefTypes {
+	for rType := range HeadRefTypes {
 		prefix := PrefixForType(rType)
 		if strings.HasPrefix(str, prefix) {
 			str = str[len(prefix):]
