@@ -30,12 +30,12 @@ import (
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env/actions/commitwalk"
-	"github.com/dolthub/dolt/go/libraries/doltcore/ref"
 	"github.com/dolthub/dolt/go/libraries/doltcore/row"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema"
 	"github.com/dolthub/dolt/go/libraries/doltcore/schema/alterschema"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dtables"
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/globalstate"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlfmt"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/sqlutil"
 	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
@@ -59,6 +59,11 @@ type Database struct {
 	rsr  env.RepoStateReader
 	rsw  env.RepoStateWriter
 	drw  env.DocsReadWriter
+
+	// todo: needs a major refactor to
+	//   correctly handle persisted sequences
+	//   that must be coordinated across txs
+	gs globalstate.GlobalState
 }
 
 var _ sql.Database = Database{}
@@ -81,28 +86,6 @@ func (db Database) StartTransaction(ctx *sql.Context) (sql.Transaction, error) {
 	return dsession.StartTransaction(ctx, db.Name())
 }
 
-func (db Database) setHeadHash(ctx *sql.Context, ref ref.WorkingSetRef) error {
-	// TODO: use the session HEAD ref here instead of the repo state one
-	// headRef, err := ref.ToHeadRef()
-	// if err != nil {
-	// 	return err
-	// }
-
-	headCommit, err := db.ddb.Resolve(ctx, db.rsr.CWBHeadSpec(), db.rsr.CWBHeadRef())
-	if err != nil {
-		return err
-	}
-	headHash, err := headCommit.HashOf()
-	if err != nil {
-		return err
-	}
-	if doltSession, ok := ctx.Session.(*dsess.Session); ok {
-		return doltSession.SetSessionVarDirectly(ctx, dsess.HeadKey(db.name), headHash.String())
-	} else {
-		return ctx.SetSessionVariable(ctx, dsess.HeadKey(db.name), headHash.String())
-	}
-}
-
 func (db Database) CommitTransaction(ctx *sql.Context, tx sql.Transaction) error {
 	dsession := dsess.DSessFromSess(ctx.Session)
 	return dsession.CommitTransaction(ctx, db.name, tx)
@@ -146,6 +129,7 @@ func NewDatabase(name string, dbData env.DbData) Database {
 		rsr:  dbData.Rsr,
 		rsw:  dbData.Rsw,
 		drw:  dbData.Drw,
+		gs:   globalstate.NewGlobalStateStore(),
 	}
 }
 
