@@ -811,6 +811,7 @@ var _ sql.IndexAlterableTable = (*AlterableDoltTable)(nil)
 var _ sql.ForeignKeyAlterableTable = (*AlterableDoltTable)(nil)
 var _ sql.ForeignKeyTable = (*AlterableDoltTable)(nil)
 var _ sql.CheckAlterableTable = (*AlterableDoltTable)(nil)
+var _ sql.PrimaryKeyAlterableTable = (*AlterableDoltTable)(nil)
 
 // AddColumn implements sql.AlterableTable
 func (t *AlterableDoltTable) AddColumn(ctx *sql.Context, column *sql.Column, order *sql.ColumnOrder) error {
@@ -1720,3 +1721,85 @@ func (t *AlterableDoltTable) constraintNameExists(ctx *sql.Context, name string)
 
 	return false, nil
 }
+
+func (t *AlterableDoltTable) CreatePrimaryKey(ctx *sql.Context, columns []sql.IndexColumn) error {
+	table, err := t.doltTable(ctx)
+	if err != nil {
+		return err
+	}
+
+	table, err = alterschema.AddPrimaryKeyToTable(ctx, table, t.tableName, t.nbf, columns)
+	if err != nil {
+		return err
+	}
+
+	root, err := t.getRoot(ctx)
+	if err != nil {
+		return err
+	}
+
+	// Update the root with the new table
+	newRoot, err := root.PutTable(ctx, t.tableName, table)
+	if err != nil {
+		return err
+	}
+
+	err = t.setRoot(ctx, newRoot)
+	if err != nil {
+		return err
+	}
+
+	return t.updateFromRoot(ctx, newRoot)
+}
+
+func (t *AlterableDoltTable) DropPrimaryKey(ctx *sql.Context) error {
+	// Ensure that no auto increment requirements exist on this table
+	if t.autoIncCol.AutoIncrement {
+		return sql.ErrWrongAutoKey.New()
+	}
+
+	// Ensure that any primary key column is neither a parent nor child in a fk relationship
+	root, err := t.getRoot(ctx)
+	if err != nil {
+		return err
+	}
+
+	fkc, err := root.GetForeignKeyCollection(ctx)
+	if err != nil {
+		return err
+	}
+
+	err = t.sch.GetPKCols().Iter(func(tag uint64, col schema.Column) (bool, error) {
+		if fkc.ColumnHasFkRelationship(tag) {
+			return true, sql.ErrCantDropIndex.New("PRIMARY")
+		}
+
+		return false, nil
+	})
+	if err != nil {
+		return err
+	}
+
+	table, err := t.doltTable(ctx)
+	if err != nil {
+		return err
+	}
+
+	table, err = alterschema.DropPrimaryKeyFromTable(ctx, table, t.nbf)
+	if err != nil {
+		return err
+	}
+
+	// Update the root with then new table
+	newRoot, err := root.PutTable(ctx, t.tableName, table)
+	if err != nil {
+		return err
+	}
+
+	err = t.setRoot(ctx, newRoot)
+	if err != nil {
+		return err
+	}
+
+	return t.updateFromRoot(ctx, newRoot)
+}
